import React,{ Component } from 'react'
import { View, TextInput,Text } from 'react-native'
import defaultTheme from './Theme'

class Input extends Component {
  constructor(props) {
    super(props)
    this.state = {
      value:props.defaultValue
    }
    this.onValueChange = this.onValueChange.bind(this)
  }

  componentWillReceiveProps(nextProps) {

    this.setState({
      value: nextProps.defaultValue
    })
  }

  onValueChange(newValue) {
    this.setState({
      value:newValue
    },() => {
      this.props.onValueChange(newValue)
    })
  }

  render() {

    const { value } = this.state
    const { childIndex } = this.props

    let wrapStyle = {
      borderTopWidth:0,
      borderColor:'#CCC'
    }
    if(childIndex != 0) {
      wrapStyle = {
        borderTopWidth:1,
        borderColor:'#CCC'
      }
    }

    return (
      <View
        style={[this.props.theme.BaseItem,wrapStyle]}
      >
        <View style={this.props.theme.BaseItem_Left}>
          <Text style={this.props.theme.Label}>{this.props.label}</Text>
        </View>
        <View style={this.props.theme.BaseItem_Right}>
          <TextInput
            style={[{
              color: '#333333',
              fontSize: 16,
              justifyContent: 'flex-end',
              flex:1
            },this.props.valueStyle]}
            textAlign={'right'}
            defaultValue={ value.toString() }
            editable={this.props.editable}
            placeholder={this.props.placeholder}
            onChangeText={this.onValueChange}
          />
        </View>
      </View>
    )
  }
}

Input.PropTypes = {
  defaultValue:React.PropTypes.oneOf([
    React.PropTypes.string,
    React.PropTypes.number
  ]),
  editable:React.PropTypes.boolean,
  onValueChange: React.PropTypes.func.isRequired,
  childIndex: React.PropTypes.number,
  // valueStyle: React.PropTypes
}

Input.defaultProps = {
  componentName: 'Input',
  theme: defaultTheme,
  editable: true,
  defaultValue:'',
  onValueChange:() => {},
  childIndex:0,
  valueStyle:{}
}

export default Input
