import React, { Component } from 'react'
import {
  Modal,
  Picker,
  Text,
  TouchableOpacity,
  View,
  StatusBar
} from 'react-native'
import Icon from 'react-native-vector-icons/FontAwesome'
import defaultTheme from './Theme'

class Select extends Component {
  constructor(props) {
    super(props)

    this.state = {
      showSelector: false,
      value: props.defaultValue
    }

    this.toggleSelector = this.toggleSelector.bind(this)
    this.onValueChange = this.onValueChange.bind(this)
  }

  componentWillReceiveProps(nextProps) {

    this.setState({
      value: nextProps.defaultValue
    })
  }

  toggleSelector() {
    this.setState({
      showSelector: !this.state.showSelector
    })
  }

  onValueChange(newValue) {
    this.setState({
      showSelector: false,
      value: newValue
    }, () => {
      this.props.onValueChange(newValue)
    })
  }

  render() {
    const {
      labelKey,
      valueKey,
      options,
      childIndex
    } = this.props;
    const { showSelector, value } = this.state

    let wrapStyle = {
      borderTopWidth:0,
      borderColor:'#CCC'
    }
    if(childIndex != 0) {
      wrapStyle = {
        borderTopWidth:1,
        borderColor:'#CCC'
      }
    }

    let labelsByValue = {};
    for(let i = 0;i < options.length;i++) {

      labelsByValue[options[i][valueKey]] = options[i][labelKey];
    }

    let label = ''
    if(value) {
      label = labelsByValue[value]
    }



    return (
      <View style={wrapStyle}>
        <Modal
          onRequestClose={this.toggleSelector}
          visible={showSelector}
        >
          <Picker
            selectedValue={value}
            onValueChange={this.onValueChange}
          >
            {
              options.map(option => {
                const label = option[labelKey]
                const value = option[valueKey]

                return <Picker.Item key={value} label={label} value={value} />
              })
            }
          </Picker>
        </Modal>
        <TouchableOpacity onPress={ this.toggleSelector }>
          <View style={this.props.theme.BaseItem}>
            <View style={this.props.theme.BaseItem_Left}>
              <Text style={this.props.theme.Label}>{this.props.label}</Text>
            </View>
            <View style={this.props.theme.BaseItem_Right}>
              <Text style={{fontSize:16}}>{ label }</Text>
              <Icon name="chevron-right" size={16} color="#CCC" />
            </View>
          </View>
        </TouchableOpacity>
      </View>
    )
  }
}

Select.PropTypes = {
  placeholder: React.PropTypes.string,
  labelKey: React.PropTypes.string,
  valueKey: React.PropTypes.string,
  defaultValue: React.PropTypes.oneOf([
    React.PropTypes.string,
    React.PropTypes.number
  ]),
  options: React.PropTypes.array.isRequired,
  onValueChange: React.PropTypes.func.isRequired,
  childIndex: React.PropTypes.number
}

Select.defaultProps = {
  componentName: 'Select',
  theme:defaultTheme,
  childIndex:0,
  placeholder:'',
  labelKey:'key',
  valueKey:'value',
  defaultValue:'',
  options:[],
  onValueChange:() => {}
}

export default Select;
